@@ -2,7 +2,7 @@
 mod tests;
 
 use crate::consumer::RtpStreamParams;
-use crate::data_structures::{AppData, TraceEventDirection};
+use crate::data_structures::{AppData, RtpPacketTraceInfo, SsrcTraceInfo, TraceEventDirection};
 use crate::messages::{
     ProducerCloseRequest, ProducerDumpRequest, ProducerEnableTraceEventData,
     ProducerEnableTraceEventRequest, ProducerGetStatsRequest, ProducerInternal,
@@ -21,7 +21,6 @@ use event_listener_primitives::{Bag, BagOnce, HandlerId};
 use log::{debug, error};
 use parking_lot::Mutex;
 use serde::{Deserialize, Serialize};
-use serde_json::Value;
 use serde_repr::{Deserialize_repr, Serialize_repr};
 use std::collections::HashMap;
 use std::fmt;
@@ -48,7 +47,6 @@ pub struct ProducerOptions {
     pub(super) id: Option<ProducerId>,
     /// Media kind.
     pub kind: MediaKind,
-    // TODO: Docs have distinction between RtpSendParameters and RtpReceiveParameters
     /// RTP parameters defining what the endpoint is sending.
     pub rtp_parameters: RtpParameters,
     /// Whether the producer must start in paused mode. Default false.
@@ -217,9 +215,8 @@ pub enum ProducerTraceEventData {
         timestamp: u64,
         /// Event direction.
         direction: TraceEventDirection,
-        // TODO: Clarify value structure
-        /// Per type specific information.
-        info: Value,
+        /// RTP packet info.
+        info: RtpPacketTraceInfo,
     },
     /// RTP video keyframe packet.
     KeyFrame {
@@ -227,9 +224,8 @@ pub enum ProducerTraceEventData {
         timestamp: u64,
         /// Event direction.
         direction: TraceEventDirection,
-        // TODO: Clarify value structure
-        /// Per type specific information.
-        info: Value,
+        /// RTP packet info.
+        info: RtpPacketTraceInfo,
     },
     /// RTCP NACK packet.
     Nack {
@@ -237,9 +233,6 @@ pub enum ProducerTraceEventData {
         timestamp: u64,
         /// Event direction.
         direction: TraceEventDirection,
-        // TODO: Clarify value structure
-        /// Per type specific information.
-        info: Value,
     },
     /// RTCP PLI packet.
     Pli {
@@ -247,9 +240,8 @@ pub enum ProducerTraceEventData {
         timestamp: u64,
         /// Event direction.
         direction: TraceEventDirection,
-        // TODO: Clarify value structure
-        /// Per type specific information.
-        info: Value,
+        /// SSRC info.
+        info: SsrcTraceInfo,
     },
     /// RTCP FIR packet.
     Fir {
@@ -257,9 +249,8 @@ pub enum ProducerTraceEventData {
         timestamp: u64,
         /// Event direction.
         direction: TraceEventDirection,
-        // TODO: Clarify value structure
-        /// Per type specific information.
-        info: Value,
+        /// SSRC info.
+        info: SsrcTraceInfo,
     },
 }
 
@@ -792,11 +783,6 @@ impl DirectProducer {
     }
 }
 
-// TODO: Remove with next major version
-#[deprecated(note = "Please use `PipedProducer` instead, it is an alias to the same type")]
-#[doc(hidden)]
-pub type NonClosingProducer = PipedProducer;
-
 /// Same as [`Producer`], but will not be closed when dropped.
 ///
 /// The idea here is that [`ProducerId`] of both original [`Producer`] and `PipedProducer` is the
